@@ -1,5 +1,5 @@
 package Dist::Zooky::App::Command::dist;
-$Dist::Zooky::App::Command::dist::VERSION = '0.16';
+$Dist::Zooky::App::Command::dist::VERSION = '0.18';
 # ABSTRACT: The one command that Dist::Zooky uses
 
 use strict;
@@ -11,13 +11,17 @@ sub abstract { 'Dist::Zooky!' }
 sub opt_spec {
   return (
       [ 'make=s', 'Specify make utility to use', ],
+      [ 'bundle=s', 'Specify a plugin bundle to write to the dist.ini file', ],
   );
 }
 
 sub execute {
   my ($self, $opt, $args) = @_;
   require Dist::Zooky;
-  my $zooky = Dist::Zooky->new( ( defined $opt->{make} ? ( make => $opt->{make} ) : () ) );
+  my $zooky = Dist::Zooky->new(
+    ( defined $opt->{make} ? ( make => $opt->{make} ) : () ),
+    ( defined $opt->{bundle} ? ( bundle => $opt->{bundle} ) : () )
+  );
   $zooky->examine;
   return;
 }
@@ -36,7 +40,7 @@ Dist::Zooky::App::Command::dist - The one command that Dist::Zooky uses
 
 =head1 VERSION
 
-version 0.16
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -59,7 +63,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Chris Williams.
+This software is copyright (c) 2017 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
