@@ -1,5 +1,5 @@
 package Dist::Zooky::DistIni;
-$Dist::Zooky::DistIni::VERSION = '0.16';
+$Dist::Zooky::DistIni::VERSION = '0.18';
 # ABSTRACT: Generates a Dist::Zilla dist.ini file
 
 use strict;
@@ -24,14 +24,22 @@ has 'metadata' => (
   required => 1,
 );
 
-my $template = q|
-name = {{ $name }}
+has 'bundle' => (
+  is => 'ro',
+  isa => 'Str',
+);
+
+my $temphead =
+q|name = {{ $name }}
 version = {{ $version }}
 {{ $OUT .= join "\n", map { "author = $_" } @authors; }}
 {{ $OUT .= join "\n", map { "license = $_" } @licenses; }}
 {{ ( my $holder = $authors[0] ) =~ s/\s*\<.+?\>\s*//g; "copyright_holder = $holder"; }}
 
-[GatherDir]
+|;
+
+my $tempstd =
+q|[GatherDir]
 [PruneCruft]
 [ManifestSkip]
 [MetaYAML]
@@ -51,8 +59,7 @@ version = {{ $version }}
 [Manifest]
 [TestRelease]
 [ConfirmRelease]
-[UploadToCPAN]
-|;
+[UploadToCPAN]|;
 
 sub write {
   my $self = shift;
@@ -63,6 +70,7 @@ sub write {
     for qw(configure build runtime);
   $stash{$_} = $self->metadata->{$_} for qw(author license version name);
   $stash{"${_}s"} = delete $stash{$_} for qw(author license);
+  my $template = $temphead . ( $self->bundle ? q|[@| . $self->bundle . qq|]| : $tempstd );
   my $content = $self->fill_in_string(
     $template,
     \%stash,
@@ -100,7 +108,7 @@ Dist::Zooky::DistIni - Generates a Dist::Zilla dist.ini file
 
 =head1 VERSION
 
-version 0.16
+version 0.18
 
 =head1 SYNOPSIS
 
@@ -163,7 +171,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Chris Williams.
+This software is copyright (c) 2017 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
